/* libiso8601/src/libiso8601/000_TopHeader.h
 *
 *  (c)2006-2010, Laurence Withers, <l@lwithers.me.uk>.
 *  Released under the GNU GPLv3. See file COPYING or
 *  http://www.gnu.org/copyleft/gpl.html for details.
*/

#ifndef HEADER_libiso8601
#define HEADER_libiso8601

#ifdef __cplusplus
extern "C" {
#endif

/* standard includes, or includes needed for type declarations */
#include <time.h>
#include <stdint.h>
#include <sys/time.h>

/* options for text editors
kate: replace-trailing-space-save true; space-indent true; tab-width 4;
vim: expandtab:ts=4:sw=4
*/
